function choix = choixC (i, des)
% La fonction "choixC" indique, étant donné l'étape "i" du jeu à laquelle
% on se situe et le 5-vecteur "des" des résultats affichés par les dés,
% quels sont les dés que la stratégie de Charlotte amène à choisir de
% relancer ou non.

% Déclaration des variables globales
global N_DES SEUIL CHIFFRE_MAX CHIFFRE_MIN;
% On fait d'abord un choix “naïf”, sans tenir compte des contraintes
% évidentes.
if (i == 1)
    choix = (des < 5);
elseif (i == 2)
    choix = (des < 4);
end
% Il faut aussi tenir compte des conditions évidentes sur la stratégie.
% Pour cela, on commence par classer les numéros dans l'ordre, comme dans
% "choixX".
classement = zeros (1, N_DES);
ordonnes = zeros (1, N_DES);
for i = 1 : N_DES
    record = CHIFFRE_MIN - 1;
    for j = 1 : N_DES
        if (~classement(j))
            valeur = des(j);
            if (valeur > record)
                record = valeur;
                recordman = j;
            end
        end
    end
    classement(recordman) = i;
    ordonnes(i) = record;
end
% On force maintenant les conditions évidentes à être satisfaites. En
% particulier, il faut vérifier qu'on a bien relancé assez de dés pour
% arriver à la valeur 24. Pour cela, on imagine d'abord qu'on garde tous
% les dés, puis 4 puis 3, etc (on désigne le nombre de dés qu'on envisage
% de garder par "agarder") ; et on regarde comment évolue le total
% potentiel "total" qu'on obtiendrait si chaque dé relancé donnait un 6.
total = sum (des);
for agarder = N_DES : -1 : 0
    if (total >= SEUIL)
        break;
    end
    % On envisage à chaque fois de garder un dé de moins ; et on regarde
    % donc ce que deviendrait le total si ce dé relancé tombait sur 6.
    total = total - ordonnes(agarder) + CHIFFRE_MAX;
end
% On s'assure qu'on a bien relancé le nombre minimal de dés.
for i = 1 : N_DES
    choix = choix | (classement > agarder);
end
% Il faut ausi s'assurer qu'on ne relance pas les dés si on a déjà obtenu
% le score de 24.
if (sum (des) >= SEUIL)
    choix = zeros (1, N_DES);
end
% On peut maintenant renvoyer la liste des dés à relancer.
return;
end