function choix = choixX (~, des)
% La fonction "choixX" indique, étant donné le 5-vecteur "des" des
% résultats affichés par les dés, quels sont les dés que la stratégie de
% Xénia amène à choisir de relancer (valeur true) ou non (valeur
% false). On notera que le numéro du tour impliqué, bien qu'intervenant
% dans la syntaxe de la fonction, n'est en fait pas utilisé.

% Déclaration des variables globales
global N_DES SEUIL CHIFFRE_MIN;

% Pour commencer, il faut ranger les dés du plus grand au plus petit.
% "classement" vaudra 1 pour le plus grand dé, 2 pour le suivant, etc. (les
% ex-æquo sont triés arbitrairement), et "ordonnes" correspond aux numéros
% des dés rangés dans cet ordre.
classement = zeros (1, N_DES);
ordonnes = zeros (1, N_DES);
for i = 1 : N_DES
    % On appelle "record" la plus grande valeur trouvée pour un dé non
    % encore classé, et "recordman" le numéro du dé correspondant à cette
    % valeur.
    record = CHIFFRE_MIN - 1;
    for j = 1 : N_DES
        if (~classement(j))
            valeur = des(j);
            if (valeur > record)
                record = valeur;
                recordman = j;
            end
        end
    end
    classement(recordman) = i;
    ordonnes(i) = record;
end
% Maintenant il faut regarder combien de dés on peut garder sans passer
% en-dessous de 24/5 de moyenne. "agarder" est le nombre de dés que, pour
% l'instant, on pense pouvoir garder ; et "total" est le total des dés
% qu'on est en train de considérer.
total = 0;
for agarder = 0 : N_DES
    % Si on peut garder N_DES dés, inutile d'aller plus loin !
    if (agarder == N_DES)
        break;
    end
    % On regarde le dé suivant, par ordre décroissant.
    total = total + ordonnes(agarder + 1);
    % Je regarde si la moyenne des dés considérés, à savoir total / i, est
    % encore supérieure ou égale à 24 / 5. J'exprime la condition à l'aide
    % de nombres entiers, ce qui évitera toute erreur d'arrondi.
    if (total * N_DES < SEUIL * (agarder + 1))
        break;
    end
end
% La valeur de agarder déterminée à l'étape précédente permet de déterminer
% le choix “naïf” de Xénia, càd. la conclusion de sa stratégie si on
% omet de considérer les conditions évidentes.
choix = zeros (1, N_DES);
for i = 1 : N_DES
    choix(i) = (classement(i) > agarder);
end
% Avec la stratégie de Xénia, la seule contrainte évident qu'on est
% susceptible de ne pas satisfaire serait qu'on pourrait oublier de
% relancer des dés affichant pourtant 1 ; nous allons donc forcer cette
% contrainte avant de renvoyer la liste des dés à relancer.
choix = choix | (des == CHIFFRE_MIN);
return;
end